@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-citeproc
 version: 0.9.1.1
-id: pandoc-citeproc-0.9.1.1-1d27415813eae935b120436dc23bd090
-key: pando_FR7BIejKllo93qfJu872TX
+id: pandoc-citeproc-0.9.1.1-26de2ff2cab65872a11f6945922d6e10
+key: pando_9SGyRBrgInU6nLiTK0Qs4K
 license: BSD3
 maintainer: jgm@berkeley.edu
 homepage: https://github.com/jgm/pandoc-citeproc
@@ -42,7 +42,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 data-dir: /usr/share/pandoc-citeproc
-hs-libraries: HSpandoc-citeproc-0.9.1.1-FR7BIejKllo93qfJu872TX
+hs-libraries: HSpandoc-citeproc-0.9.1.1-9SGyRBrgInU6nLiTK0Qs4K
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -54,7 +54,7 @@ depends:
     hs-bibutils-5.5-91f8c150a94b021e3f1d7580075e1ca0
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    pandoc-1.17.0.3-a12df7a7745e5ea4de39fe36e7ff7b76
+    pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
     pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
@@ -66,7 +66,7 @@ depends:
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
+    xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
     yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
 haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
 haddock-html: /usr/share/doc/pandoc-citeproc/html
